@@ -1,10 +1,12 @@
 package Log::Log4perl::Shortcuts ;
-$Log::Log4perl::Shortcuts::VERSION = '0.009';
+$Log::Log4perl::Shortcuts::VERSION = '0.010';
 use 5.10.0;
 use Carp;
 use Log::Log4perl;
 use Log::Log4perl::Level;
-use File::HomeDir;
+use Path::Tiny;
+use Module::Data;
+use File::UserConfig;
 use Data::Dumper qw(Dumper);
 
 require Exporter;
@@ -13,30 +15,31 @@ require Exporter;
 %EXPORT_TAGS = ( all => [qw(logc logt logd logi logw loge logf change_config_file set_log_level)] );
 Exporter::export_ok_tags('all');
 
-BEGIN {
-  our $config_dir = '/perl/log_config/';
-  our $current_config = 'default2.cfg';
-  our $home_dir = File::HomeDir->my_home;
-  my $file = $home_dir . $config_dir . $current_config;
-  if (!-f $file) {
-    Log::Log4perl->init_once('config/default.cfg');
-  } else {
-    Log::Log4perl->init_once($file);
-  }
-};
+my $package = __PACKAGE__;
+$package =~ s/::/-/g;
+my $config_dir = path(File::UserConfig->new(dist => $package)->configdir, 'config');
+
+my $default_config_file = path($config_dir, 'default.cfg');
+
+if (!$default_config_file->exists) {
+  carp ("Unable to load default Log::Log4perl::Shortcuts configuration file. Aborting");
+} else {
+  Log::Log4perl->init_once($default_config_file->canonpath);
+}
 
 my $log_level = $TRACE;
 
-
 ### Public methods ###
 
 sub change_config_file {
-  $current_config = shift;
-  my $file = $home_dir . $config_dir . $current_config;
-  if (!-f $file) {
-    carp ("Configuration file $file does not exist. Configuration file unchanged.");
+  my $new_config = shift;
+
+  my $path = path($config_dir, $new_config);
+  if (!$path->is_file) {
+    carp ("Configuration file $path->canonpath does not exist. Configuration file unchanged."
+      . " Place your custom log configuration file in $config_dir.");
   } else {
-    Log::Log4perl->init($file);
+    Log::Log4perl->init($path->canonpath);
     return 'success';
   }
 }
@@ -157,7 +160,7 @@ Log::Log4perl::Shortcuts - shortcut functions to make log4perl even easier
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 OVERVIEW
 
@@ -260,12 +263,16 @@ C<change_config_file> function to switch to it.
 
 =item * L<Exporter|Exporter>
 
-=item * L<File::HomeDir|File::HomeDir>
+=item * L<File::UserConfig|File::UserConfig>
 
 =item * L<Log::Log4perl|Log::Log4perl>
 
 =item * L<Log::Log4perl::Level|Log::Log4perl::Level>
 
+=item * L<Module::Data|Module::Data>
+
+=item * L<Path::Tiny|Path::Tiny>
+
 =back
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
@@ -308,7 +315,7 @@ L<https://github.com/sdondley/Log-Log4perl-Shortcuts>
 =head1 BUGS AND LIMITATIONS
 
 You can make new bug reports, and view existing ones, through the
-web interface at L<http://github.com/sdondley/Log-Log4perl-Shortcuts/issues>.
+web interface at L<https://github.com/sdondley/Log-Log4perl-Shortcuts/issues>.
 
 =head1 INSTALLATION
 
